Crate axum_conditional_requests

Crate axum_conditional_requests 

Structs

IfModifiedSince
Only implements OptionalFromRequestParts to force the user to handle the case of ignoring this header, as extracting this header is not supposed to error out, but MUST instead be ignored.
LastModified
MaybeUnmodified