IfModifiedSince

Struct IfModifiedSince 

pub struct IfModifiedSince(/* private fields */);
Only implements OptionalFromRequestParts to force the user to handle the case of ignoring this header, as extracting this header is not supposed to error out, but MUST instead be ignored.