Crate axum_conditional_requests
axum_
conditional_
requests
0.1.2
All Items
Crate Items
Structs
Crate
axum_
conditional_
requests
Structs

IfModified
Since
Only implements OptionalFromRequestParts to force the user to handle the case of ignoring this header, as extracting this header is not supposed to error out, but MUST instead be ignored.
Last
Modified
Maybe
Unmodified